@@ -192,8 +192,9 @@ ebbm_pick_book_view (EBookBackendMAPI *ebma)
 		return NULL;
 	}
 
+	e_iterator_last (iter);
 	if (e_iterator_is_valid (iter)) {
-		/* just always use the first book view */
+		/* just always use the last book view */
 		EDataBookView *v = (EDataBookView *) e_iterator_get (iter);
 		if (v)
 			rv = v;
@@ -205,6 +206,30 @@ ebbm_pick_book_view (EBookBackendMAPI *ebma)
 	return rv;
 }
 
+static void
+complete_views (EBookBackendMAPI *ebma)
+{
+	EList *views;
+	EIterator *iter;
+
+	g_return_if_fail (ebma != NULL);
+
+	views = e_book_backend_get_book_views (E_BOOK_BACKEND (ebma));
+	if (!views)
+		return;
+
+	for (iter = e_list_get_iterator (views); iter && e_iterator_is_valid (iter); e_iterator_next (iter)) {
+		EDataBookView *book_view = (EDataBookView *) e_iterator_get (iter);
+
+		if (book_view)
+			e_data_book_view_notify_complete (book_view, NULL);
+	}
+
+	if (iter)
+		g_object_unref (iter);
+	g_object_unref (views);
+}
+
 struct FetchContactsData
 {
 	glong last_notification;
@@ -298,7 +323,6 @@ ebbm_update_cache_cb (gpointer data)
 	EBookBackendMAPIPrivate *priv;
 	EBookBackendMAPIClass *ebmac;
 	glong last_modification_secs = 0;
-	EDataBookView *book_view;
 	GError *error = NULL;
 
 	g_return_val_if_fail (ebma != NULL, NULL);
@@ -376,9 +400,7 @@ ebbm_update_cache_cb (gpointer data)
 	if (error)
 		g_error_free (error);
 
-	book_view = ebbm_pick_book_view (ebma);
-	if (book_view)
-		e_data_book_view_notify_complete (book_view, NULL);
+	complete_views (ebma);
 
 	/* indicate the thread is not running */
 	g_cancellable_cancel (priv->update_cache);
@@ -1914,15 +1936,10 @@ mapi_book_utils_contact_from_props (ExchangeMapiConnection *conn, mapi_id_t fid,
 				e_contact_set (contact, mappings[i].field_id, value);
 		} else if (contact_type == ELEMENT_TYPE_SIMPLE) {
 			if (value && mappings[i].element_type == PT_SYSTIME) {
-				struct FILETIME *t = value;
-				time_t time;
-				NTTIME nt;
+				const struct FILETIME *t = value;
 				gchar buff[129];
+				time_t time = exchange_mapi_util_filetime_to_time_t (t);
 
-				nt = t->dwHighDateTime;
-				nt = nt << 32;
-				nt |= t->dwLowDateTime;
-				time = nt_time_to_unix (nt);
 				e_contact_set (contact, mappings[i].field_id, ctime_r (&time, buff));
 			}
 		} else if (contact_type == ELEMENT_TYPE_COMPLEX) {
@@ -1934,18 +1951,15 @@ mapi_book_utils_contact_from_props (ExchangeMapiConnection *conn, mapi_id_t fid,
 				g_list_free (list);
 			} else if (mappings[i].field_id == E_CONTACT_BIRTH_DATE
 				   || mappings[i].field_id == E_CONTACT_ANNIVERSARY) {
-				struct FILETIME *t = value;
+				const struct FILETIME *t = value;
 				time_t time;
-				NTTIME nt;
 				struct tm * tmtime;
 				if (value) {
 					EContactDate date = {0};
-					nt = t->dwHighDateTime;
-					nt = nt << 32;
-					nt |= t->dwLowDateTime;
-					time = nt_time_to_unix (nt);
+
+					time = exchange_mapi_util_filetime_to_time_t (t);
 					tmtime = gmtime (&time);
-					//FIXME: Move to new libmapi api to get string dates.
+
 					date.day = tmtime->tm_mday;
 					date.month = tmtime->tm_mon + 1;
 					date.year = tmtime->tm_year + 1900;
